@@ -208,6 +208,10 @@
     )
   )
   rm(tmp)
+
+  GSOD_XY$MAX_FLAG[GSOD_XY$MAX_FLAG == ""] <- NA
+  GSOD_XY$MIN_FLAG[GSOD_XY$MIN_FLAG == ""] <- NA
+
   tibble::as_tibble(GSOD_XY)
   return(GSOD_XY)
 }
